==> fox-1.1.1.tar.gz: fox/src/Drush/Commands/FoxCommands.php <==
<?php

namespace Drupal\fox\Drush\Commands;

use Consolidation\SiteAlias\SiteAliasManagerAwareInterface;
use Consolidation\SiteAlias\SiteAliasManagerAwareTrait;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\fox\FoxEntityQuery;
use Drupal\fox\Plugin\FoxCommandsManager;
use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
class FoxCommands extends DrushCommands implements SiteAliasManagerAwareInterface {

  use SiteAliasManagerAwareTrait;

  /**
   * Options list.
   *
   * @var array
   */
  protected $options;

  /**
   * Variables list.
   *
   * @var array
   */
  protected $variables = [];

  /**
   * Constructs a FoxCommands object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly FoxCommandsManager $foxCommandsManager,
    private readonly FoxEntityQuery $foxEntityQuery,
  ) {
    parent::__construct();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.fox_commands'),
      $container->get('fox.query.entity'),
    );
  }

  /**
   * Fox console.
   */
  #[CLI\Command(name: 'fox:console', aliases: ['fox'])]
  #[CLI\Option(name: 'input', description: 'Input commands: "command1;command2"')]
  #[CLI\Option(name: 'output', description: 'Output command history')]
  #[CLI\Option(name: 'mode', description: 'Command mode: default|debug')]
  public function console(array $options = [
    'input' => '',
    'mode' => 'default',
  ]) {
    $this->options = $options;
    $this->io()->info(dt("Welcome to the Fox console!"));
    $commands_history = [];

    // Variables for executing external drush commands.
    $this->variables['self'] = $this->siteAliasManager()->getSelf();
    $this->variables['process_manager'] = $this->processManager();

    // Enter the interactive loop.
    while (TRUE) {
      if (!empty($options['input'])) {
        $input = trim($options['input']);
        $options['input'] = NULL;
      }
      else {
        $input = $this->io()->ask(dt('Enter a command (type "exit" or "quit" to quit)'));
      }
      $input = strtolower(trim($input));

      // All commands.
      $commands = array_filter(explode(';', $input));
      foreach ($commands as $command) {
        $command = trim($command);

        // Check for exit condition.
        if (in_array($command, ['exit', 'quit'])) {
          $this->io()->info('Exiting the Fox console.');

          // Output commands.
          if (!empty($options['output'])) {
            $header = [
              '#',
              dt('Command'),
            ];
            $output = [];
            foreach ($commands_history as $number => $data) {
              $output[] = [$number + 1, $data];
            }
            $this->io()->table($header, $output);
          }
          return;
        }

        $completed = FALSE;

        // Fox commands.
        if (!$completed) {
          $result = $this->parseFoxCommands($command);
          if (!empty($result)) {
            $this->setVariables($result);
            $success = $this->printResult($result);
            if ($success) {
              $commands_history[] = $command;
            }
            $completed = TRUE;
          }
        }

        // Run Entity Query.
        if (!$completed) {
          $result = $this->foxEntityQuery->doEntityQuery($command, $this->variables, $this->options);
          if (!empty($result)) {
            $this->setVariables($result);
            $success = $this->printResult($result);
            if ($success) {
              $commands_history[] = $command;
            }
            $completed = TRUE;
          }
        }

        // Print variables.
        $this->printVariables();
      }
    }
  }

  /**
   * Fox commands parse.
   *
   * @param string $input
   *   User input.
   *
   * @return string
   *   Output message.
   */
  protected function parseFoxCommands(string $input) {
    $foxCommands = $this->foxCommandsManager->getDefinitions();

    $params = array_filter(explode(' ', $input), function ($value) {
      if (is_numeric($value)) {
        return TRUE;
      }
      return !empty($value);
    });
    $command = strtolower($params[0]);
    if (!empty($foxCommands[$command])) {
      array_shift($params);
      $instance = $this->foxCommandsManager->createInstance($command);
      $result = $instance->execute($params, $this->variables);
      return $result;
    }

    return NULL;
  }

  /**
   * Print variables.
   */
  protected function printVariables(): void {
    $message = '';
    foreach ($this->variables as $name => $value) {
      if ($value !== NULL) {
        if (is_array($value)) {
          foreach ($value as $name2 => $value2) {
            if ($value2 !== NULL) {
              $message .= "$name2=\"$value2\" ";
            }
          }
        }
        elseif (!is_object($value)) {
          $message .= "$name=\"$value\" ";
        }
      }
    }
    $this->output->writeln($message);
  }

  /**
   * Print result.
   *
   * @param array $result
   *   Command result.
   *
   * @return bool
   *   Success result output.
   */
  protected function printResult(array $result): bool {
    if (empty($result)) {
      return TRUE;
    }

    if (isset($result['error'])) {
      $this->io()->error($result['error']);
      return FALSE;
    }

    if (isset($result['debug'])) {
      $this->io()->info($result['debug']);
    }

    $message = $result['message'] ?? NULL;
    if (!empty($message)) {
      if (is_array($message)) {
        $keys = array_keys($message);
        if (count($keys) >= 2 && in_array('header', $keys) && in_array('data', $keys)) {
          $message = [$message];
        }
        $this->printTable($message);
      }
      else {
        $this->output()->writeln($message);
      }

      return TRUE;
    }
  }

  /**
   * Print table.
   *
   * @param array $arr
   *   Data for table output.
   */
  protected function printTable(array $arr): void {
    foreach ($arr as $index => $data) {
      if (is_string($index)) {
        $this->output()->writeln($index);
      }

      if (empty($data['data'])) {
        $this->io()->warning(dt('Empty data'));
      }
      else {
        if (!empty($data['horizontal'])) {
          $this->io()->horizontalTable($data['header'], $data['data']);
        }
        else {
          $this->io()->table($data['header'], $data['data']);
        }
      }
    }
  }

  /**
   * Set local variables.
   *
   * @param array $result
   *   Command result.
   */
  protected function setVariables($result): void {
    $variables = $result['variables'] ?? NULL;
    if (!$variables) {
      return;
    }

    foreach ($variables as $name => $value) {
      if (is_array($value)) {
        foreach ($value as $name2 => $value2) {
          $this->variables[$name2] = $value2;
        }
      }
      elseif (!is_object($value)) {
        $this->variables[$name] = $value;
      }
    }
  }

}

==> fox-1.1.3.tar.gz: fox/src/Drush/Commands/FoxCommands.php <==
<?php

namespace Drupal\fox\Drush\Commands;

use Consolidation\SiteAlias\SiteAliasManagerAwareInterface;
use Consolidation\SiteAlias\SiteAliasManagerAwareTrait;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\fox\FoxEntityQuery;
use Drupal\fox\Plugin\FoxCommandsManager;
use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
class FoxCommands extends DrushCommands implements SiteAliasManagerAwareInterface {

  use SiteAliasManagerAwareTrait;

  /**
   * Options list.
   *
   * @var array
   */
  protected $options;

  /**
   * Variables list.
   *
   * @var array
   */
  protected $variables = [];

  /**
   * Constructs a FoxCommands object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly FoxCommandsManager $foxCommandsManager,
    private readonly FoxEntityQuery $foxEntityQuery,
  ) {
    parent::__construct();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.fox_commands'),
      $container->get('fox.query.entity'),
    );
  }

  /**
   * Fox console.
   */
  #[CLI\Command(name: 'fox:console', aliases: ['fox'])]
  #[CLI\Option(name: 'input', description: 'Input commands: "command1;command2"')]
  #[CLI\Option(name: 'output', description: 'Output command history')]
  #[CLI\Option(name: 'mode', description: 'Command mode: default|debug')]
  public function console(
    array $options = [
      'input' => '',
      'mode' => 'default',
    ],
  ) {
    $this->options = $options;
    $this->io()->info(dt("Welcome to the Fox console!"));
    $commands_history = [];

    // Variables for executing external drush commands.
    $this->variables['self'] = $this->siteAliasManager()->getSelf();
    $this->variables['process_manager'] = $this->processManager();

    // Enter the interactive loop.
    while (TRUE) {
      if (!empty($options['input'])) {
        $input = trim($options['input']);
        $options['input'] = NULL;
      }
      else {
        $input = $this->io()->ask(dt('Enter a command (type "exit" or "quit" to quit)'));
      }
      $input = strtolower(trim($input));

      // All commands.
      $commands = array_filter(explode(';', $input));
      foreach ($commands as $command) {
        $command = trim($command);

        // Check for exit condition.
        if (in_array($command, ['exit', 'quit'])) {
          $this->io()->info('Exiting the Fox console.');

          // Output commands.
          if (!empty($options['output'])) {
            $header = [
              '#',
              dt('Command'),
            ];
            $output = [];
            foreach ($commands_history as $number => $data) {
              $output[] = [$number + 1, $data];
            }
            $this->io()->table($header, $output);
          }
          return;
        }

        $completed = FALSE;

        // Fox commands.
        if (!$completed) {
          $result = $this->parseFoxCommands($command);
          if (!empty($result)) {
            $this->setVariables($result);
            $success = $this->printResult($result);
            if ($success) {
              $commands_history[] = $command;
            }
            $completed = TRUE;
          }
        }

        // Run Entity Query.
        if (!$completed) {
          $result = $this->foxEntityQuery->doEntityQuery($command, $this->variables, $this->options);
          if (!empty($result)) {
            $this->setVariables($result);
            $success = $this->printResult($result);
            if ($success) {
              $commands_history[] = $command;
            }
            $completed = TRUE;
          }
        }

        // Print variables.
        $this->printVariables();
      }
    }
  }

  /**
   * Fox commands parse.
   *
   * @param string $input
   *   User input.
   *
   * @return string
   *   Output message.
   */
  protected function parseFoxCommands(string $input) {
    $foxCommands = $this->foxCommandsManager->getDefinitions();

    $params = array_filter(explode(' ', $input), function ($value) {
      if (is_numeric($value)) {
        return TRUE;
      }
      return !empty($value);
    });
    $command = strtolower($params[0]);
    if (!empty($foxCommands[$command])) {
      array_shift($params);
      $instance = $this->foxCommandsManager->createInstance($command);
      $result = $instance->execute($params, $this->variables);
      return $result;
    }

    return NULL;
  }

  /**
   * Print variables.
   */
  protected function printVariables(): void {
    $message = '';
    foreach ($this->variables as $name => $value) {
      if ($value !== NULL) {
        if (is_array($value)) {
          foreach ($value as $name2 => $value2) {
            if ($value2 !== NULL) {
              $message .= "$name2=\"$value2\" ";
            }
          }
        }
        elseif (!is_object($value)) {
          $message .= "$name=\"$value\" ";
        }
      }
    }
    $this->output->writeln($message);
  }

  /**
   * Print result.
   *
   * @param array $result
   *   Command result.
   *
   * @return bool
   *   Success result output.
   */
  protected function printResult(array $result): bool {
    if (empty($result)) {
      return TRUE;
    }

    if (isset($result['error'])) {
      $this->io()->error($result['error']);
      return FALSE;
    }

    if (isset($result['debug'])) {
      $this->io()->info($result['debug']);
    }

    $message = $result['message'] ?? NULL;
    if (!empty($message)) {
      if (is_array($message)) {
        $keys = array_keys($message);
        if (count($keys) >= 2 && in_array('header', $keys) && in_array('data', $keys)) {
          $message = [$message];
        }
        $this->printTable($message);
      }
      else {
        $this->output()->writeln($message);
      }

      return TRUE;
    }
  }

  /**
   * Print table.
   *
   * @param array $arr
   *   Data for table output.
   */
  protected function printTable(array $arr): void {
    foreach ($arr as $index => $data) {
      if (is_string($index)) {
        $this->output()->writeln($index);
      }

      if (empty($data['data'])) {
        $this->io()->warning(dt('Empty data'));
      }
      else {
        if (!empty($data['horizontal'])) {
          $this->io()->horizontalTable($data['header'], $data['data']);
        }
        else {
          $this->io()->table($data['header'], $data['data']);
        }
      }
    }
  }

  /**
   * Set local variables.
   *
   * @param array $result
   *   Command result.
   */
  protected function setVariables($result): void {
    $variables = $result['variables'] ?? NULL;
    if (!$variables) {
      return;
    }

    foreach ($variables as $name => $value) {
      if (is_array($value)) {
        foreach ($value as $name2 => $value2) {
          $this->variables[$name2] = $value2;
        }
      }
      elseif (!is_object($value)) {
        $this->variables[$name] = $value;
      }
    }
  }

}
